@@ -23,9 +23,9 @@ pecCtree <- function(...){
  out  
 }
 
-##' @S3method predictSurvProb pecCtree
+##' @export 
 predictSurvProb.pecCtree <- function (object, newdata, times, ...) {
-    require(party)
+    requireNamespace("party")
     N <- NROW(newdata)
     NT <- length(times)
     survObj <- party::treeresponse(object$ctree, newdata=newdata)
